from .Gaussiandistribution import work_ones
from .Generaldistribution import work_two


def helps():  # поддержка
    print("'work_ones' :'")
    print('get_vowels - Получаем гласные')
    print('capitalize - Первая буква в верхнем регистре')
    print('check_duplicate - Проверка дубликатов ')
    print('Filtering - Фильтрация значений ')
    print('ByteSize - Размер в байтах ')
    print('anagrams - Анаграммы ')
    print('palindrome - Проверка палиндромов ')
    print("'work_two' :'")
    print('chunk - Разбиение на фрагменты ')
    print('merge - Объединяем два словаря ')
